@@ -3,7 +3,7 @@ package App::MineralUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-15'; # DATE
 our $DIST = 'App-MineralUtils'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -80,7 +80,8 @@ our %argspecs_magnesium = (
     quantity => {
         # schema => 'physical::mass*', # XXX Perinci::Sub::GetArgs::Argv is not smart enough to coerce from string
         schema => 'str*',
-        req => 1,
+        default => '1 mg',
+        req => 0,
         pos => 0,
         completion => sub {
             require Complete::Sequence;
@@ -121,7 +122,7 @@ _
     },
     examples => [
         {
-            args=>{quantity=>'mg'},
+            args=>{},
             summary=>'Show all possible conversions',
         },
         {
@@ -159,14 +160,15 @@ sub convert_magnesium_unit {
             @magnesium_forms,
         ) {
             push @rows, {
-                unit => $u->{name},
                 amount => $quantity->convert($u->{name}),
+                unit => $u->{name},
+                summary => $u->{summary},
             };
         }
         [200, "OK", \@rows, {
-            'table.fields' => [qw/amount unit/],
-            'table.field_formats'=>[[number=>{thousands_sep=>'', precision=>3}], undef],
-            'table.field_aligns' => [qw/number left/],
+            'table.fields' => [qw/amount unit summary/],
+            'table.field_formats'=>[[number=>{thousands_sep=>'', precision=>3}], undef, undef],
+            'table.field_aligns' => [qw/number left left/],
         }];
     }
 }
@@ -186,7 +188,7 @@ App::MineralUtils - Utilities related to mineral supplements
 
 =head1 VERSION
 
-This document describes version 0.004 of App::MineralUtils (from Perl distribution App-MineralUtils), released on 2021-08-15.
+This document describes version 0.005 of App::MineralUtils (from Perl distribution App-MineralUtils), released on 2021-08-15.
 
 =head1 DESCRIPTION
 
@@ -215,7 +217,7 @@ Examples:
 
 =item * Show all possible conversions:
 
- convert_magnesium_unit(quantity => "mg");
+ convert_magnesium_unit();
 
 Result:
 
@@ -223,22 +225,70 @@ Result:
    200,
    "OK",
    [
-     { amount => 1, unit => "mg-mg-elem" },
-     { amount => 8.84955752212389, unit => "mg-mg-citrate" },
-     { amount => 6.28930817610063, unit => "mg-mg-citrate-ah" },
-     { amount => 6.89655172413793, unit => "mg-mg-citrate-ah-nowfoods" },
-     { amount => 7.09219858156028, unit => "mg-mg-glycinate" },
-     { amount => 7.09219858156028, unit => "mg-mg-bisglycinate" },
-     { amount => 10, unit => "mg-mg-bisglycinate-nowfoods" },
-     { amount => 13.5135135135135, unit => "mg-mg-ascorbate" },
-     { amount => 13.5135135135135, unit => "mg-mg-pidolate" },
-     { amount => 12.0481927710843, unit => "mg-mg-l-threonate" },
-     { amount => 1.65837479270315, unit => "mg-mg-oxide" },
+     {
+       amount  => 1,
+       unit    => "mg-mg-elem",
+       summary => "Elemental magnesium, in milligrams",
+     },
+     {
+       amount  => 8.84955752212389,
+       unit    => "mg-mg-citrate",
+       summary => "Magnesium citrate (C6H6MgO7), in milligrams",
+     },
+     {
+       amount  => 6.28930817610063,
+       unit    => "mg-mg-citrate-ah",
+       summary => "Magnesium citrate anhydrous (C6H5Mg3O7), in milligrams",
+     },
+     {
+       amount  => 6.89655172413793,
+       unit    => "mg-mg-citrate-ah-nowfoods",
+       summary => "Magnesium citrate in NOW Foods supplement (anhydrous, C6H5Mg3O7, 90.9% pure, contains citric acid etc), in milligrams",
+     },
+     {
+       amount  => 7.09219858156028,
+       unit    => "mg-mg-glycinate",
+       summary => "Magnesium glycinate/bisglycinate (C4H8MgN2O4), in milligrams",
+     },
+     {
+       amount  => 7.09219858156028,
+       unit    => "mg-mg-bisglycinate",
+       summary => "Magnesium glycinate/bisglycinate (C4H8MgN2O4), in milligrams",
+     },
+     {
+       amount  => 10,
+       unit    => "mg-mg-bisglycinate-nowfoods",
+       summary => "Magnesium bisglycinate in NOW Foods supplement (C4H8MgN2O4, 70.5% pure, contains citric acid etc), in milligrams",
+     },
+     {
+       amount  => 13.5135135135135,
+       unit    => "mg-mg-ascorbate",
+       summary => "Magnesium ascorbate/pidolate (C11H13MgNO9), in milligrams",
+     },
+     {
+       amount  => 13.5135135135135,
+       unit    => "mg-mg-pidolate",
+       summary => "Magnesium ascorbate/pidolate (C11H13MgNO9), in milligrams",
+     },
+     {
+       amount  => 12.0481927710843,
+       unit    => "mg-mg-l-threonate",
+       summary => "Magnesium L-threonate (C8H14MgO10), in milligrams",
+     },
+     {
+       amount  => 1.65837479270315,
+       unit    => "mg-mg-oxide",
+       summary => "Magnesium oxide (MgO), in milligrams",
+     },
    ],
    {
-     "table.field_formats" => [["number", { thousands_sep => "", precision => 3 }], undef],
-     "table.field_aligns"  => ["number", "left"],
-     "table.fields"        => ["amount", "unit"],
+     "table.field_aligns"  => ["number", "left", "left"],
+     "table.field_formats" => [
+                                ["number", { precision => 3, thousands_sep => "" }],
+                                undef,
+                                undef,
+                              ],
+     "table.fields"        => ["amount", "unit", "summary"],
    },
  ]
 
@@ -282,7 +332,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<quantity>* => I<str>
+=item * B<quantity> => I<str> (default: "1 mg")
 
 =item * B<to_unit> => I<str>
 
